@@ -52,10 +52,10 @@ IaOraConfig::IaOraConfig(TDEConfig* config, TQWidget* parent)
     load(config);
 
     // setup the connections
-    connect(m_dialog->menuClose, SIGNAL(toggled(bool)),
-            this, SIGNAL(changed()));
-    connect(m_dialog->titleShadow, SIGNAL(toggled(bool)),
-            this, SIGNAL(changed()));
+    connect(m_dialog->menuClose, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(changed()));
+    connect(m_dialog->titleShadow, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(changed()));
 }
 
 IaOraConfig::~IaOraConfig()
