@@ -27,6 +27,8 @@
 #include <tqimage.h>
 #include <tqapplication.h>
 #include <tdeconfig.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kpixmap.h>
 #include <kpixmapeffect.h>
 
@@ -41,6 +43,9 @@ namespace KWinIaOra
 
 IaOraHandler::IaOraHandler()
 {
+    TDEGlobal::locale()->insertCatalogue("twin_clients");
+    TDEGlobal::locale()->insertCatalogue("twin_iaora");
+
     memset(m_pixmaps, 0, sizeof(TQPixmap*)*NumPixmaps*2*2); // set elements to 0
     memset(m_bitmaps, 0, sizeof(TQBitmap*)*NumButtonIcons*2);
 
